searchData={"items":[{"type":"module","title":"Instructor","doc":"Instructor is a library for structured prompting of LLMs.\n\nSee Instructor.chat_completion/1 for more information on how to use it.\n\nBy default we use the OpenAI adapter, but you can configure your own adapter by setting the `:adapter` config value.","ref":"Instructor.html"},{"type":"module","title":"Configuration - Instructor","doc":"Instructor can be configured in your `config.exs` file:\n\n      config :instructor, adapter: Instructor.Adapters.OpenAI\n\n  Other adapters are Instructor.Adapters.Llamacpp","ref":"Instructor.html#module-configuration"},{"type":"function","title":"Instructor.chat_completion/1","doc":"Create a new chat completion for the provided messages and parameters.\n\nThe parameters are passed directly to the LLM adapter.\nBy default they shadow the OpenAI API parameters.\nFor more information on the parameters, see the [OpenAI API docs](https://platform.openai.com/docs/api-reference/chat-completions/create).\n\nAdditionally, the following parameters are supported:\n\n  * `:response_model` - The Ecto schema to validate the response against.","ref":"Instructor.html#chat_completion/1"},{"type":"function","title":"Examples - Instructor.chat_completion/1","doc":"iex> Instructor.chat_completion(%{\n  ...>   model: \"gpt-3.5-turbo\",\n  ...>   response_model: Instructor.Demos.SpamPrediction,\n  ...>   messages: [\n  ...>     %{\n  ...>       role: \"user\",\n  ...>       content: \"Classify the following text: Hello, I am a Nigerian prince and I would like to give you $1,000,000.\"\n  ...>     }\n  ...> })\n  {:ok,\n      %Instructor.Demos.SpamPrediction{\n          class: :spam\n          score: 0.999\n      }}","ref":"Instructor.html#chat_completion/1-examples"},{"type":"behaviour","title":"Instructor.Adapter","doc":"Behavior for `Instructor.Adapter`.","ref":"Instructor.Adapter.html"},{"type":"callback","title":"Instructor.Adapter.chat_completion/2","doc":"","ref":"Instructor.Adapter.html#c:chat_completion/2"},{"type":"module","title":"Instructor.Adapters.Llamacpp","doc":"Runs against the llama.cpp server. To be clear this calls the llamacpp specific\nendpoints, not the open-ai compliant ones.\n\nYou can read more about it here:\n  https://github.com/ggerganov/llama.cpp/tree/master/examples/server","ref":"Instructor.Adapters.Llamacpp.html"},{"type":"function","title":"Instructor.Adapters.Llamacpp.chat_completion/2","doc":"Run a completion against the llama.cpp server, not the open-ai compliant one.\nThis gives you more specific control over the grammar, and the ability to\nprovide other parameters to the specific LLM invocation.\n\nYou can read more about the parameters here:\n  https://github.com/ggerganov/llama.cpp/tree/master/examples/server","ref":"Instructor.Adapters.Llamacpp.html#chat_completion/2"},{"type":"function","title":"Examples - Instructor.Adapters.Llamacpp.chat_completion/2","doc":"iex> Instructor.chat_completion(%{\n  ...>   model: \"mistral-7b-instruct\",\n  ...>   messages: [\n  ...>     %{ role: \"user\", content: \"Classify the following text: Hello I am a Nigerian prince and I would like to send you money!\" },\n  ...>   ],\n  ...>   response_model: response_model,\n  ...>   temperature: 0.5,\n  ...> })","ref":"Instructor.Adapters.Llamacpp.html#chat_completion/2-examples"},{"type":"module","title":"Instructor.Adapters.OpenAI","doc":"Documentation for `Instructor.Adapters.OpenAI`.","ref":"Instructor.Adapters.OpenAI.html"},{"type":"module","title":"Instructor.GBNF","doc":"","ref":"Instructor.GBNF.html"},{"type":"function","title":"Instructor.GBNF.from_json_schema/1","doc":"","ref":"Instructor.GBNF.html#from_json_schema/1"},{"type":"module","title":"Instructor.JSONSchema","doc":"","ref":"Instructor.JSONSchema.html"},{"type":"function","title":"Instructor.JSONSchema.from_ecto_schema/1","doc":"Generates a JSON Schema from an Ecto schema.\n\n  Note: This will output a correct JSON Schema for the given Ecto schema, but\n  it will not necessarily be optimal, nor support all Ecto types.","ref":"Instructor.JSONSchema.html#from_ecto_schema/1"},{"type":"behaviour","title":"Instructor.Validator","doc":"","ref":"Instructor.Validator.html"},{"type":"callback","title":"Instructor.Validator.validate_changeset/1","doc":"","ref":"Instructor.Validator.html#c:validate_changeset/1"},{"type":"extras","title":"instructor_ex","doc":"# instructor_ex\n\n_Structured, Ecto outputs with OpenAI (and OSS LLMs)_\n\n---\n\n[![KinoShell version](https://img.shields.io/hexpm/v/instructor_ex.svg)](https://hex.pm/packages/instructor_ex)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/instructor_ex/)\n[![GitHub stars](https://img.shields.io/github/stars/thmsmlr/instructor_ex.svg)](https://github.com/thmsmlr/instructor_ex/stargazers)\n[![Twitter Follow](https://img.shields.io/twitter/follow/thmsmlr?style=social)](https://twitter.com/thmsmlr)\n\n\nInstructor.ex is a spiritual port of the great [Instructor Python Library](https://github.com/jxnl/instructor) by [@jxnlco](https://twitter.com/jxnlco).\nThis library brings structured prompting to LLMs. Instead of receiving text as output, Instructor will coax the LLM to output valid JSON that maps directly to the provided Ecto schema.\nIf the LLM fails to do so, or provides values that do not pass your validations, it will provide you utilities to automatically retry with the LLM to correct errors.\nBy default it's designed to be used with the [OpenAI API](https://platform.openai.com/docs/api-reference/chat-completions/create), however it provides an extendable adapter behavior to work with [ggerganov/llama.cpp](https://github.com/ggerganov/llama.cpp) and [Bumblebee (Coming Soon!)](https://github.com/elixir-nx/bumblebee).\n\nAt it's simplest, usage is pretty straight forward,\n\n```elixir\ndefmodule SpamPredicition do\n  use Ecto.Schema\n  use Instructor.Validator\n\n  @doc \"\"\"","ref":"readme.html"},{"type":"extras","title":"Field Descriptions: - instructor_ex","doc":"- class: Whether or not the email is spam\n  - reason: A short, less than 10 word rationalization for the classification\n  - score: A confidence score between 0.0 and 1.0 for the classification\n  \"\"\"\n  @primary_key false\n  embedded_schema do\n    field(:class, Ecto.Enum, values: [:spam, :not_spam])\n    field(:reason, :string)\n    field(:score, :float)\n  end\n\n  @impl true\n  def validate_changeset(changeset) do\n    changeset\n    |> Ecto.Changeset.validate_number(:score,\n      greater_than_or_equal_to: 0.0,\n      less_than_or_equal_to: 1.0\n    )\n  end\nend\n\nis_spam? = fn text ->\n  Instructor.chat_completion(\n    model: \"gpt-3.5-turbo\",\n    response_model: SpamPredicition,\n    messages: [\n      %{\n        role: \"user\",\n        content: \"\"\"\n        You purpose is to classify customer support emails as either spam or not.\n        This is for a clothing retailer business.\n        They sell all types of clothing.\n\n        Classify the following email: #{text}\n        \"\"\"\n      }\n    ]\n  )\nend\n\nis_spam?.(\"Hello I am a Nigerian prince and I would like to send you money\")\n\n# => {:ok, %SpamPredicition{class: :spam, reason: \"Nigerian prince email scam\", score: 0.98}}\n```\n\nSimply create an ecto schema, optionally provide a `@doc` to the schema definition which we pass down to the LLM, then make a call to `Instructor.chat_completion/1` with contect about the task you'd like the LLM to complete.","ref":"readme.html#field-descriptions"},{"type":"extras","title":"Installation - instructor_ex","doc":"```elixir\ndef deps do\n  [\n    {:instructor, \"~> 0.0.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"TODO - instructor_ex","doc":"- [x] Tests\n    - [x] JSONSchema\n    - [x] gbnf\n- [x] Add JSONSchema --> GBNF computation\n- [x] Add field descriptions\n- [x] Add validators\n- [ ] Cleanup large with, add typespecs and docs\n- [ ] Retry Logic\n- [ ] llamacpp should handle all messages values, not just first system and first user\n- [ ] Support binaries and binary_id in JSONSchema and GBNF\n- [ ] Verify :naive_datetime support","ref":"readme.html#todo"}],"content_type":"text/markdown"}